/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.registry;

import java.util.Collection;

import net.smartlab.web.BusinessException;
import net.smartlab.web.DAOException;
import net.smartlab.web.DataAccessObject.SearchInfo;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public class Domain extends net.smartlab.web.Domain {

	/* # net.smartlab.web.registry.EntryFactory factory */
	/**
	 * Singleton instance statically initialized.
	 */
	private final static Domain instance = new Domain();

	private final static DeduplicationStrategy strategy = new GenericDeduplicationStrategy();


	/**
	 * Blocks class instantiation to enforce the singleton pattern.
	 */
	private Domain() {
		super();
	}

	/**
	 * @return the singleton instance.
	 */
	public static synchronized Domain getInstance() {
		return instance;
	}

	/**
	 * TODO documentation
	 * 
	 * @param id
	 * @return
	 * @throws BusinessException
	 */
	public Entry findEntry(String id) throws BusinessException {
		try {
			return (Entry)EntryFactory.getInstance().findByKey(Long.valueOf(id));
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param infos
	 * @return
	 * @throws BusinessException
	 */
	public Collection listEntries(SearchInfo infos) throws BusinessException {
		try {
			return EntryFactory.getInstance().page(infos);
		} catch (DAOException bofe) {
			throw new BusinessException(bofe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param id
	 * @param string
	 * @throws BusinessException
	 */
	public void removeEntry(String id) throws BusinessException {
		try {
			EntryFactory.getInstance().remove(this.findEntry(id));
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param entry
	 * @throws BusinessException
	 */
	public void updateEntry(Entry entry) throws BusinessException {
		try {
			EntryFactory.getInstance().update(entry);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param entity
	 * @return
	 * @throws BusinessException
	 */
	public Collection listDuplicates(Entity entity) throws BusinessException {
		try {
			return EntityFactory.getInstance().listDuplicates(entity, strategy);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param listId
	 * @param lastname
	 * @param firstname
	 * @return
	 * @throws BusinessException
	 * @Deprecated use  pagePersonByList
	 * @see pagePersonByList(String listId,SearchInfo searchInfo)
	 * 
	 */
	public Collection pagePersonByListLastnameFirstname(long listId, String lastname, String firstname) throws BusinessException {
		try {
			return PersonFactory.getInstance().pageByListLastnameFirstname(listId, lastname, firstname);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param listId
	 * @param display
	 * @return
	 * @throws BusinessException
	 */
	public Collection pageEntryByListDisplay(long listId, String display) throws BusinessException {
		try {
			return EntryFactory.getInstance().pageByListDisplay(listId, display);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 *
	 * @param listId
	 * @param searchInfo
	 * @return
	 * @throws BusinessException
	 */
	public Collection pagePersonByList(String listId,SearchInfo searchInfo) throws BusinessException {
		try {
			long idList=0;
			try{
				idList=Long.parseLong(listId);
			}catch(Exception e){
				//DO NOTHING
			}
			return PersonFactory.getInstance().pageByList(idList, searchInfo);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	/**
	 * TODO documentation
	 * 
	 * @param listId
	 * @return
	 * @throws BusinessException
	 */
	public Collection listEntityByList(long listId) throws BusinessException {
		try {
			return EntityFactory.getInstance().listByList(listId);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}

	public Collection pageListByListDisplay(long listId, String display) throws BusinessException {
		try {
			return ListFactory.getInstance().pageByListDisplay(listId, display);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}
	/**
	 * 
	 * @TODO documentation
	 * @param listId
	 * @param lastname
	 * @param firstname
	 * @param anotherListId
	 * @return
	 * @throws BusinessException
	 */
	public Collection pagePersonByListLastnameFirstname(long listId,String lastname,String firstname,long anotherListId) throws BusinessException{
		try {
			SearchInfo info=new SearchInfo();
			if(lastname!=null && lastname.length()>0)
				info.addFilter("name.lastname",SearchInfo.LIKE,lastname);
			if(lastname!=null && lastname.length()>0)
				info.addFilter("name.firstname",SearchInfo.LIKE,firstname);
			return PersonFactory.getInstance().pageByNotInList(listId,anotherListId, info);
		} catch (DAOException daoe) {
			throw new BusinessException(daoe);
		}
	}
}