/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
 
package net.smartlab.web.registry;

import java.util.Collection;
import java.util.Iterator;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;

import net.smartlab.web.AbstractArchiveAction;
import net.smartlab.web.ActionException;
import net.smartlab.web.BusinessException;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public class EntryAction extends AbstractArchiveAction {

	/**
	 * TODO documentation Comment for <code>domain</code>
	 */
	private Domain domain = Domain.getInstance();

	/**
	 * @see net.smartlab.web.AbstractArchiveAction#search(org.apache.struts.action.ActionForm,
	 *      javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse,
	 *      org.apache.struts.action.ActionMapping)
	 */
	public String search(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			Collection entries = domain.listEntries(super.getSearchInfo(request));
			request.setAttribute("entries", entries);
			return "success";
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}

	}

	/**
	 * @see net.smartlab.web.AbstractArchiveAction#select(org.apache.struts.action.ActionForm,
	 *      javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse,
	 *      org.apache.struts.action.ActionMapping)
	 */
	public String select(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			Entry entry = domain.findEntry(request.getParameter("id"));
			request.setAttribute("entry", entry);
			if (form != null && !super.hasErrors(request)) {
				super.reset(form, request, mapping);
				super.populate(form, entry, request.getLocale());
			}
			return "success";
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}
	}

	/**
	 * @see net.smartlab.web.AbstractArchiveAction#update(org.apache.struts.action.ActionForm,
	 *      javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse,
	 *      org.apache.struts.action.ActionMapping)
	 */
	public String update(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			Entry entry = null;
			if (super.isChecked("group", request)) {
				entry = new List();
				String[] entries = super.getSelection(form, "user-selection");
				if (entries != null) {
					for (int i = 0; i < entries.length; i++) {
						((List)entry).add(domain.findEntry(entries[i]));
					}
				}
			} else {
				// FIXME
				entry = null; //new Entity();
			}
			super.valorize(form, entry, request.getLocale());
			domain.updateEntry(entry);
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}
		return "success";
	}

	/**
	 * @see net.smartlab.web.AbstractArchiveAction#remove(org.apache.struts.action.ActionForm,
	 *      javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse,
	 *      org.apache.struts.action.ActionMapping)
	 */
	public String remove(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			domain.removeEntry(request.getParameter("id"));
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}
		return "success";
	}

	/**
	 * @see net.smartlab.web.AbstractArchiveAction#removeAll(org.apache.struts.action.ActionForm,
	 *      javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse,
	 *      org.apache.struts.action.ActionMapping)
	 */
	public String removeAll(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			String[] ids = super.getListSelection(request);
			for (int i = 0; i < ids.length; i++) {
				domain.removeEntry(ids[i]);
			}
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}
		return "success";
	}

	/**
	 * TODO documentation
	 * 
	 * @param form
	 * @param request
	 * @param response
	 * @param mapping
	 * @return
	 * @throws ActionException
	 */
	public String entries(ActionForm form, HttpServletRequest request, HttpServletResponse response, ActionMapping mapping) throws ActionException {
		try {
			Entry entry = domain.findEntry(request.getParameter("id"));
			request.setAttribute("entry", entry);
			List list = (List)entry;
			Collection entries = list.getEntries();
			String[] selection = new String[entries.size()];
			Iterator selected = entries.iterator();
			for (int i = 0; selected.hasNext(); i++) {
				Entry member = (Entry)selected.next();
				selection[i] = Long.toString(member.getId());
			}
			((DynaActionForm)form).set("entry-selection", selection);
			request.setAttribute("entries", domain.listEntries(super.getSearchInfo(request)));
			return "success";
		} catch (BusinessException be) {
			throw new ActionException(be.getMessage(), be.getCause());
		}
	}
}