/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
 
package net.smartlab.web.registry;

import java.util.Collection;

import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.criterion.Expression;
import org.hibernate.criterion.Order;

import net.smartlab.web.BusinessObjectFactory;
import net.smartlab.web.DAOException;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public class EntryFactory extends BusinessObjectFactory {

	/*# net.smartlab.web.registry.Entry bo */

	/**
	 * Singleton instance statically initialized.
	 */
	private final static EntryFactory instance = new EntryFactory();

	/**
	 * Blocks class instantiation to enforce the singleton pattern.
	 */
	private EntryFactory() {
		super();
	}

	/**
	 * @return Returns the singleton instance.
	 */
	public static EntryFactory getInstance() {
		return instance;
	}

	/**
	 * @see net.smartlab.web.BusinessObjectFactory#getMappedClass()
	 */
	public Class getMappedClass() {
		return Entry.class;
	}
	
	
	
	/**
	 * @param listId
	 * @param display
	 * @return
	 * @throws DAOException
	 */
	public Collection pageByListDisplay(long listId, String display) throws DAOException {
		try {
		    if (logger.isDebugEnabled()) {
			logger.debug("pageByListDisplay() START");
		    }
		    Session session = super.current();
		    Criteria criteria = session.createCriteria(this.getMappedClass());
		    criteria.createAlias("lists", "lists");
		    criteria.add(Expression.eq("lists.id", new Long(listId)));
		    if (display != null && display.trim().length() > 0) {
			criteria.add(Expression.ilike("display", display + "%"));
			
		    }
		    criteria.addOrder(Order.asc("display"));
		    if (logger.isDebugEnabled()) {
			logger.debug("pageByListDisplay() END");
		    }
		    return new BusinessObjectFactory.Paginator(criteria);

		} catch (HibernateException he) {
		    logger.error("listByListLastnameFirstname() ERROR :" + he.getMessage());
		    throw new DAOException("listByListLastnameFirstname() ERROR :" + he.getMessage());
		}
	    }
}