/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.registry;

/**
 * Introduced to adapt an Entry model data into a presentation layer,
 * <code>EntryHelper</code> helps you to retrieving information about
 * its own sub classes properties. 
 * 
 * @author gcontartese 
 * @author gperrone
 */
public class EntryHelper {

	/** 
	 * The entry used to obtain information
	 * @uml.property name="entry"
	 * @uml.associationEnd multiplicity="(1 1)" aggregation="composite" inverse="entryHelper:net.smartlab.web.registry.Entry"
	 * @uml.association name="wrap"
	 */
	private Entry entry;


	/**
     * Sole constructor.  (For invocation by subclass constructors, typically
     * implicit.)
     */
	public EntryHelper(){
		super();
	}
	/**
	 * Creates a new concrete EntryHelper with its related entry.
	 * @param entry
	 * @throws IllegalArgumentException if the entry to be setted is null.
	 */
	public EntryHelper(Entry entry) {
		if(entry==null) throw new IllegalArgumentException("Entry cannot be null");
		this.entry=entry;
	}

	/** 
	 * Getter of the property <tt>entry</tt>
	 * @return  Returns the entry.
	 * @uml.property  name="entry"
	 */
	public Entry getEntry() {
		return entry;
	}

	/** 
	 * Setter of the property <tt>entry</tt>
	 * @param entry  The entry to set.
	 * @uml.property  name="entry"
	 */
	public void setEntry(Entry entry) {
		this.entry = entry;
	}
}
