/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */

package net.smartlab.web.registry;

import java.util.Collection;

import net.smartlab.web.BusinessObjectFactory;
import net.smartlab.web.DAOException;
import net.smartlab.web.page.CollectionPaginator;

import org.hibernate.Criteria;
import org.hibernate.FetchMode;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.criterion.Expression;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public class ListFactory extends BusinessObjectFactory {

	/**
	 * Singleton instance statically initialized.
	 */
	private final static ListFactory instance = new ListFactory();

	/**
	 * Blocks class instantiation to enforce the singleton pattern.
	 */
	private ListFactory() {
		super();
	}

	/**
	 * @see net.smartlab.web.BusinessObjectFactory#getMappedClass()
	 */
	public Class getMappedClass() {
		return List.class;
	}

	/**
	 * @return Returns the singleton instance.
	 */
	public static ListFactory getInstance() {
		return instance;
	}

	/**
	 * @param listId
	 * @param display
	 * @return
	 * @throws DAOException
	 */
	public Collection listByListDisplay(long listId, String display) throws DAOException {
		if (logger.isDebugEnabled()) {
			logger.debug("listByListDisplay() START");
		}
		try {
			Session session = super.current();
			Criteria criteria = session.createCriteria(this.getMappedClass());
			criteria.createAlias("lists", "lists");
			criteria.add(Expression.eq("lists.id", new Long(listId)));
			criteria.setResultTransformer(Criteria.DISTINCT_ROOT_ENTITY);
			if (display != null && display.trim().length() > 0) {
				criteria.add(Expression.ilike("display", display + "%"));
			}
			if (logger.isDebugEnabled()) {
				logger.debug("listByListDisplay() END");
			}
			return criteria.list();

		} catch (HibernateException he) {
			logger.error("listByListDisplay() ERROR :" + he.getMessage());
			throw new DAOException("listByListDisplay() ERROR :" + he.getMessage());
		}
	}

	/**
	 * @param listId
	 * @param display
	 * @return
	 * @throws DAOException
	 */
	public Collection pageByListDisplay(long listId, String display) throws DAOException {
		if (logger.isDebugEnabled()) {
			logger.debug("pageByListDisplay() START");
		}
		try {
			Session session = super.current();
			String hqlQuery = "select distinct list from List list left join fetch list.entries e join list.lists parent where parent.id=" + listId;
			if (display != null && display.trim().length() > 0) {
				hqlQuery = hqlQuery + " and UPPER(list.display) LIKE '" + display.toUpperCase() + "%'";
			}
			Query query = session.createQuery(hqlQuery);
			return new CollectionPaginator(query.list());

			/*
			
			Criteria criteria = session.createCriteria(this.getMappedClass());
			criteria.createAlias("lists", "lists");
			criteria.add(Expression.eq("lists.id", new Long(listId)));
			criteria.setFetchMode("entries", FetchMode.JOIN);
			if (display != null && display.trim().length() > 0) {
			criteria.add(Expression.ilike("display", display + "%"));
			}
			if (logger.isDebugEnabled()) {
			logger.debug("pageByListDisplay() END");
			}
			criteria.setResultTransformer(Criteria.DISTINCT_ROOT_ENTITY);
			return new Paginator(criteria);
			 */

		} catch (HibernateException he) {
			logger.error("pageByListDisplay() ERROR :" + he.getMessage());
			throw new DAOException("pageByListDisplay() ERROR :" + he.getMessage());
		}
	}
	/**
     * Try to find an existence Entry defined passthrus key parameter.
     * If fetched parameter is true all its "entries" are fetched to
     * avoid LazyInitializeException in phase of re-call.
     * @param key The serializable key to retrieve the List 
     * @param fetched If true all entries are fetched.This to avoid 
     * LazyInizializeException.
     * NB.:Is strongly discouraged to use this approach to solve the problem
     * 
     * @return an List defined by key.
     * @throws DAOException If any error occurred during transaction
     */
    public Object findByKeyFatched(String key, boolean fetched) throws DAOException {
        if (fetched)
        {
            try{
                Session session = current();
                Criteria criteria = session.createCriteria(getMappedClass());
                criteria.add(Expression.eq("id", convertKey(key)));
                criteria.setFetchMode("entries", FetchMode.JOIN);
                return criteria.uniqueResult();
                
            }catch(HibernateException he)
            {
                logger.warn("findByKeyFatched(key = " + key + " fetched = " + fetched + ") - failed", he);
                throw new DAOException("errors.session.search", he);
            }
            
        }
        return super.findByKey(key);
    }
}
