/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.registry;

import java.util.Iterator;
import java.util.Set;

/**
 * The class represents the registry list helper for custom getAddress methods.
 * 
 * @author gperrone
 */
public class ListHelper extends EntryHelper {

	/**
	 * Default constructor
	 */
	public ListHelper(){
		
	}
	/**
	 * @param list
	 */
	public ListHelper(Entry entry) {
		super(entry);
	}

	/**
	 * @return
	 */
	public int getEmailAddressSize() {
		return this.getAddressSize(EmailAddress.class);
	}

	/**
	 * @return
	 */
	public int getMailAddressSize() {
		return this.getAddressSize(MailAddress.class);
	}

	/**
	 * @return
	 */
	public int getHomeAddressSize() {
		int count = 0;
		Set set = ((List)super.getEntry()).getEntries(net.smartlab.web.registry.Entity.class);
		if (set != null) {
			Iterator iter = set.iterator();
			while (iter.hasNext()) {
				EntityHelper entity = new EntityHelper((Entity)iter.next());
				if (entity.isHomeReachable()) {
					count++;
				}
			}
		}
		return count;
	}

	/**
	 * @return
	 */
	public int getMobileAddressSize() {
		int count = 0;
		Set set = ((List)super.getEntry()).getEntries(net.smartlab.web.registry.Entity.class);
		if (set != null) {
			Iterator iter = set.iterator();
			while (iter.hasNext()) {
				EntityHelper entity = new EntityHelper((Entity)iter.next());
				if (entity.isMobileReachable()) {
					count++;
				}
			}
		}
		return count;
	}

	/**
	 * @return
	 */
	public int getOfficeAddressSize() {
		int count = 0;
		Set set = ((List)super.getEntry()).getEntries(net.smartlab.web.registry.Entity.class);
		if (set != null) {
			Iterator iter = set.iterator();
			while (iter.hasNext()) {
				EntityHelper entity = new EntityHelper((Entity)iter.next());
				if (entity.isOfficeReachable()) {
					count++;
				}
			}
		}
		return count;
	}

	/**
	 * @return
	 */
	public int getFaxAddressSize() {
		int count = 0;
		Set set = ((List)super.getEntry()).getEntries(net.smartlab.web.registry.Entity.class);
		if (set != null) {
			Iterator iter = set.iterator();
			while (iter.hasNext()) {
				EntityHelper entity = new EntityHelper((Entity)iter.next());
				if (entity.isFaxReachable()) {
					count++;
				}
			}
		}
		return count;
	}

	/**
	 * @return
	 */
	public boolean isEmailReachable() {
		return this.getEmailAddressSize() > 0;
	}

	/**
	 * @return
	 */
	public boolean isMailReachable() {
		return this.getMailAddressSize() > 0;
	}

	/**
	 * @return
	 */
	public boolean isMobileReachable() {
		return this.getMobileAddressSize() > 0;
	}

	/**
	 * @return
	 */
	public boolean isHomeReachable() {
		return this.getHomeAddressSize() > 0;
	}

	/**
	 * @return
	 */
	public boolean isOfficeReachable() {
		return this.getOfficeAddressSize() > 0;
	}

	/**
	 * @return
	 */
	public boolean isFaxReachable() {
		return this.getFaxAddressSize() > 0;
	}
	
	/**
	 * @return
	 */
	public int getAddressSize(Class addressType) {
		int count = 0;
		Set set = ((List)super.getEntry()).getEntries(net.smartlab.web.registry.Entity.class);
		if (set != null) {
			Iterator iter = set.iterator();
			while (iter.hasNext()) {
				Entity entity = (Entity)iter.next();
				if (entity.getAddresses(addressType).size() > 0) {
					count++;
				}
			}
		}
		return count;
	}
}
