/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
 
package net.smartlab.web.registry;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

import net.smartlab.web.BusinessObject;

/**
 * Represents a fully qualified description of a city or town.
 * 
 * @author rlogiacco
 * @author gcontartese
 * @stereotype component
 */
public class Locality extends BusinessObject {

	private final static long serialVersionUID = 8382450593023598729L;

	/**
	 * The country.
	 *  
	 * @uml.property name="country"
	 * @uml.associationEnd aggregation="shared" inverse="locality:net.smartlab.web.registry.Country"
	 */
	private Country country = Country.UNDEFINED;
	/**
	 * The state name.
	 */
	private String state;
	/**
	 * The city name.
	 */
	private String city;

	
	/**
	 * Default constructor
	 */
	public Locality() {
		super();
	}
	/**
	 * Constructor using fields
	 * @param country the country to be set
	 * @param state the state to be set
	 * @param city the city to be set
	 */
	public Locality(String city,String state, Country country) {
		super();
		this.country = country;
		this.state = state;
		this.city = city;
	}
	/**
	 * Constructor using fields
	 * @param countryCode the country to be set by its code N/A as default
	 * @param state the state to be set
	 * @param city the city to be set
	 */
	public Locality(String city,String state, String countryCode) {
		super();
		Country country = new Country(countryCode !=null ? countryCode :"");
		this.country = country;
		this.state = state;
		this.city = city;
	}
	
	/**
	 * Returns the city name.
	 * 
	 * @hibernate.property column="`city`" length="100"
	 * @return returns the city name.
	 */
	public String getCity() {
		return city;
	}

	/**
	 * Sets the city name.
	 * 
	 * @param city the city name to set.
	 */
	public void setCity(String city) {
		this.city = city;
	}

	/**
	 * Returns the country name.
	 * 
	 * @hibernate.property column="`country`" length="2"
	 * @return  Returns the country.
	 * @uml.property  name="country"
	 */
	 
	public Country getCountry() {
		return country;
	}

	/**
	 * Sets the country name.
	 * 
	 * @param country the country name to set.
	 * @uml.property  name="country"
	 */
	public void setCountry(Country country) {
		this.country = country;
	}

	/**
	 * Returns the state name.
	 * 
	 * @hibernate.property column="`state`" length="150"
	 * @return returns the state name.
	 */
	public String getState() {
		return state;
	}

	/**
	 * Sets the state name.
	 * 
	 * @param state the state name to set.
	 */
	public void setState(String state) {
		this.state = state;
	}
	/**
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object object) {
		if (!(object instanceof Locality)){
			return false;
        }
		Locality rhs = (Locality) object;
		return new EqualsBuilder()
		.append(this.city, rhs.getCity())
		.append(this.getCountry(), rhs.getCountry())
		.append(this.getState(), rhs.getState())
		.isEquals();
		
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return new HashCodeBuilder(1816801317, 257614045)
		.append(this.city)
		.append(this.country)
		.append(this.state)
		.toHashCode();
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		ToStringBuilder sb = new ToStringBuilder(this,ToStringStyle.SHORT_PREFIX_STYLE);
		sb.append("City",this.city)
		.append("Country",this.country.getDisplay())
		.append("State",this.state);
		return sb.toString();
	}
	
}