/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
 
package net.smartlab.web.registry;

import java.io.Serializable;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Peculiar Person component to qualify a full name .
 * @author rlogiacco
 * @author gcontartese
 * @stereotype component
 */
public class Name implements Serializable,Comparable{
	
    private final static long serialVersionUID = 3262561656982956479L;
    

    /**
     * Defines prefix title name as MR or MRS 
     */
    private String title;

    /**
     * Defines the first name
     */
    private String firstname;

    /**
     * Defines the middle name
     */
    private String middlename;

    /**
     * Defines the last name
     */
    private String lastname;
    /**
     * 
     * Default constructor
     */
    public Name(){
    	super();
    }
    /**
     * 
     * Constructor using all fields.
     */
    public Name(String title ,String firstname, String middlename, String lastname){
    	super();
    	this.title = title;
    	this.firstname = firstname;
    	this.middlename = middlename;
    	this.lastname = lastname;
    }
    /**
     * Constructor using most important fields.
     * @param firstname the firstname to set 
     * @param middlename the middlename to sets
     * @param lastname the lastname to sets
     */
    public Name(String firstname, String middlename, String lastname){
    	this(null,firstname,middlename,lastname);
    }
    /**
     * Constructor using firstname and lastname fields.
     * @param firstname the firstname to set
     * @param lastname the lasttname to set
     */
    public Name(String firstname, String lastname){
    	this(null,firstname,null,lastname);
    }
    /**
     * Return th firstname
     * @return returns the firstname.
     * @hibernate.property column="`firstname`" length="250"
     */
    public String getFirstname() {
        return firstname;
    }

    /**
     * Sets the firstname
     * @param firstname the firstname to set.
     */
    public void setFirstname(String firstname) {
        this.firstname = firstname;
    }

    /**
     * Returns the lastname
     * @return returns the lastname.
     * @hibernate.property column="`lastname`" length="250"
     */
    public String getLastname() {
        return lastname;
    }

    /**
     * Stes the lastname
     * @param lastname the lastname to set.
     */
    public void setLastname(String lastname) {
        this.lastname = lastname;
    }

    /**
     * Return the middlename
     * @return returns the middlename.
     * @hibernate.property column="`middlename`" length="250"
     */
    public String getMiddlename() {
        return middlename;
    }

    /**
     * Sets the middlename
     * @param middlename the middlename to set.
     */
    public void setMiddlename(String middlename) {
        this.middlename = middlename;
    }

    /**
     * Return the title
     * @return returns the title.
     * @hibernate.property column="`title`" length="250"
     */
    public String getTitle() {
        return title;
    }

    /**
     * Sets the title
     * @param title the title to set.
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 
     * @see java.lang.Comparable#compareTo(T)
     */
	public int compareTo(Object o) {
		if(o instanceof Name){
			Name name=(Name)o;
			return (lastname+firstname).compareTo((name.getLastname()+name.getFirstname()));
		}
		return 0;
	}
	/**
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object object) {
		if (!(object instanceof Name)){
			return false;
        }
		Name rhs = (Name) object;
		return new EqualsBuilder()
		.append(this.firstname, rhs.getFirstname())
		.append(this.lastname, rhs.getLastname())
		.append(this.middlename, rhs.getMiddlename())
		.append(this.title, rhs.getTitle())
		.isEquals();
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return new HashCodeBuilder(1816801317, 257614045)
		.append(this.firstname)
		.append(this.lastname)
		.append(this.middlename)
		.append(this.title)		
		.toHashCode();
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return new ToStringBuilder(this,ToStringStyle.SHORT_PREFIX_STYLE)
		.append("Title",this.title)
		.append("firstname",this.firstname)
		.append("middlename",this.middlename)
		.append("lastname",this.lastname)
		.toString();
	}
}