/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
 
package net.smartlab.web.registry;

import java.net.MalformedURLException;
import java.net.URL;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

/**
 * Represents a fully qualified URL.
 * 
 * @author Roberto Lo Giacco
 * @see net.smartlab.web.registry.Address
 * @hibernate.joined-subclass schema="registry" table="`web-address`"
 * @hibernate.joined-subclass-key column="`id`"
 */
public class WebAddress extends Address {

	private final static long serialVersionUID = -419769087017551138L;

	/**
	 * The url property of <code>WebAddress</code> defined as simple String.
	 */
	private String url;

	
	/**
	 * Default constructor
	 */
	public WebAddress() {
		super();
	}

	
	/**
	 * Constructor using field
	 * @param url The url as string.
	 * 
	 */
	public WebAddress(String url) {
		super();
		this.url = url;
	}


	/**
	 * Getter of property url.
	 * @hibernate.property column="`url`" length="200"
	 * @return returns the email.
	 */
    protected String getUrl() {
        return url;
    }
    
    /**
     * Set the specified url property
     * @param url The url to be setted
     */
    protected void setUrl(String url) {
        this.url = url;
    }
    
	/**
	 * Create a new java.net.URL by url property
	 * @return URL the url created, <code>null</code> if the url property is not valid.
	 */
	public URL getURL() {
		try {
            return new URL(url);
        } catch (MalformedURLException murle) {
            logger.error("getURL() - failed", murle);
            return null;
        }
	}
        
    /**
     * Set the url property by a defined java.net.URL 
     * @param url The java.net.URL above specified. 
     */
    public void setURL(URL url) {
        this.url = url.toString();
    }
    
    /**
     * @see net.smartlab.web.registry.Address#getFormattedString()
     */
    public String getFormattedString(){
        return url;
    }
    /**
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object object) {
		if (!(object instanceof WebAddress)){
			return false;
        }
		WebAddress rhs = (WebAddress) object;
		return new EqualsBuilder()
		.append(this.getUrl(), rhs.getUrl())
		.isEquals();
		
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return new HashCodeBuilder(1816801317, 257614045)
		.append(this.url)
		.toHashCode();
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		ToStringBuilder sb = new ToStringBuilder(this,ToStringStyle.SHORT_PREFIX_STYLE);
		sb.append("Url",this.getUrl());
		return sb.toString();
	}
}